// SPDX-FileCopyrightText: 2023 Carl Schwan <carl@carlschwan.eu>
// SPDX-License-Identifier: LGPL-2.0-or-later

#pragma once

#include <KJob>
#include <KMime/Message>

class EwsItem;

namespace EwsMailFactory
{
enum Option {
    NoOptions,
    SaveCopy = 0x1,
};
Q_DECLARE_FLAGS(Options, Option)
QString create(const KMime::Message::Ptr &message, Options options = NoOptions);
};
